from setuptools import setup

setup(name='stats_distro',
      version='0.1',
      description='Binomial and Gaussian distributions and some functionalitites',
      packages=['stats_distro'],
      author = 'Kunal Sharma',
      author_email = 'kushkunal077@gmail.com',
      zip_safe=False)
